**Pymicro** is an open-source Python package to work with material microstructures and 3d data sets.

.. image:: https://readthedocs.org/projects/pymicro/badge/?version=latest
   :target: https://readthedocs.org/projects/pymicro/?badge=latest
   :alt: Read the Docs

.. image:: https://travis-ci.org/heprom/pymicro.svg?branch=master
   :target: https://travis-ci.org/heprom/pymicro
   :alt: Travis CI

.. image:: https://img.shields.io/badge/License-MIT-blue.svg
   :target: https://opensource.org/licenses/MIT
   :alt: License MIT

